==> kubernetes-model-policy-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/RunAsUserStrategyOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RunAsUserStrategyOptionsBuilder extends RunAsUserStrategyOptionsFluentImpl<RunAsUserStrategyOptionsBuilder> implements VisitableBuilder<RunAsUserStrategyOptions,RunAsUserStrategyOptionsBuilder>{
  public RunAsUserStrategyOptionsBuilder() {
    this(false);
  }
  public RunAsUserStrategyOptionsBuilder(Boolean validationEnabled) {
    this(new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRanges(instance.getRanges());
      fluent.withRule(instance.getRule());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance) {
    this(instance,false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRanges(instance.getRanges());
      this.withRule(instance.getRule());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RunAsUserStrategyOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public RunAsUserStrategyOptions build() {
    RunAsUserStrategyOptions buildable = new RunAsUserStrategyOptions(fluent.getRanges(),fluent.getRule());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-policy-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/RunAsUserStrategyOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RunAsUserStrategyOptionsBuilder extends RunAsUserStrategyOptionsFluent<RunAsUserStrategyOptionsBuilder> implements VisitableBuilder<RunAsUserStrategyOptions,RunAsUserStrategyOptionsBuilder>{
  public RunAsUserStrategyOptionsBuilder() {
    this(false);
  }
  public RunAsUserStrategyOptionsBuilder(Boolean validationEnabled) {
    this(new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());

    if (instance != null) {
      fluent.withRanges(instance.getRanges());
      fluent.withRule(instance.getRule());
      fluent.withRanges(instance.getRanges());
      fluent.withRule(instance.getRule());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance) {
    this(instance,false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());

    if (instance != null) {
      this.withRanges(instance.getRanges());
      this.withRule(instance.getRule());
      this.withRanges(instance.getRanges());
      this.withRule(instance.getRule());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RunAsUserStrategyOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public RunAsUserStrategyOptions build() {
    RunAsUserStrategyOptions buildable = new RunAsUserStrategyOptions(fluent.buildRanges(),fluent.getRule());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
